/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.common.callcontext;

import java.util.Optional;
import java.util.UUID;
import java.util.logging.Level;

import org.springframework.context.ApplicationContext;

import lombok.RequiredArgsConstructor;
import lombok.extern.java.Log;

@Log
@RequiredArgsConstructor
public class DefaultOzgCloudCallContextProvider implements OzgCloudCallContextProvider {

	private final ApplicationContext context;

	@Override
	public CallContext provideContext() {
		return CallContext.builder()
				.clientName(getClientName())
				.requestId(UUID.randomUUID().toString())
				.build();
	}

	private String getClientName() {
		return Optional.ofNullable(context.getId()).orElseGet(() -> {
			LOG.log(Level.WARNING, "No Client name given. Please configure 'spring.application.name'.");
			return "unkown_client";
		});

	}
}
