/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.file.dummy;

import java.io.IOException;
import java.io.OutputStream;

import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.stereotype.Service;

import de.ozgcloud.apilib.file.OzgCloudFile;
import de.ozgcloud.apilib.file.OzgCloudFileId;
import de.ozgcloud.apilib.file.OzgCloudFileService;
import de.ozgcloud.common.errorhandling.TechnicalException;

@Service
@ConditionalOnMissingBean(OzgCloudFileService.class)
public class DummyOzgCloudFileService implements OzgCloudFileService {

	private static final byte[] TEST_DATA = "Hello World!".getBytes();

	public static final OzgCloudFile DUMMY_FILE = OzgCloudFile.builder()
			.id(OzgCloudFileId.from("42"))
			.contentType("text/plain")
			.size(TEST_DATA.length)
			.name("helloWorld.txt")
			.build();

	@Override
	public OzgCloudFile getFile(OzgCloudFileId id) {
		return DUMMY_FILE;
	}

	@Override
	public void writeFileDataToStream(OzgCloudFileId id, OutputStream streamToWriteData) {
		try {
			streamToWriteData.write(TEST_DATA);
		} catch (IOException e) {
			throw new TechnicalException("Erro wrting dummy data.", e);
		}
	}

}
