/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.file.grpc;

import java.io.IOException;
import java.io.OutputStream;
import java.util.concurrent.CompletableFuture;

import de.ozgcloud.common.errorhandling.TechnicalException;
import de.ozgcloud.vorgang.grpc.binaryFile.GrpcGetBinaryFileDataResponse;
import io.grpc.stub.StreamObserver;
import lombok.AccessLevel;
import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor(access = AccessLevel.PROTECTED)
class OzgCloudFileDownloadStreamObserver implements StreamObserver<GrpcGetBinaryFileDataResponse> {

	private final CompletableFuture<Boolean> streamFuture;
	private final OutputStream out;

	@Override
	public void onNext(GrpcGetBinaryFileDataResponse response) {
		writeToStream(response.getFileContent().toByteArray());
	}

	void writeToStream(byte[] contentPart) {
		try {
			out.write(contentPart);
		} catch (IOException e) {
			throw new TechnicalException("Download file error writing on OutputStream", e);
		}
	}

	@Override
	public void onError(Throwable t) {
		streamFuture.completeExceptionally(t);
	}

	@Override
	public void onCompleted() {
		streamFuture.complete(true);
	}
}
