/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.user;

import de.ozgcloud.apilib.common.callcontext.OzgCloudCallContextAttachingInterceptor;
import de.ozgcloud.apilib.common.callcontext.OzgCloudCallContextProvider;
import de.ozgcloud.user.grpc.userprofile.UserProfileServiceGrpc.UserProfileServiceBlockingStub;
import de.ozgcloud.user.userprofile.GrpcGetUserProfileRequest;
import lombok.RequiredArgsConstructor;
import net.devh.boot.grpc.client.inject.GrpcClient;

@RequiredArgsConstructor
public class GrpcOzgCloudUserProfileService implements OzgCloudUserProfileService {

	@GrpcClient("user-manager")
	private final UserProfileServiceBlockingStub serviceStub;

	private final UserProfileMapper mapper;

	private final OzgCloudCallContextProvider contextProvider;

	@Override
	public OzgCloudUserProfile getById(OzgCloudUserId userId) {
		var grpcUserProfileResponse = getUserProfileServiceStub().getById(buildGetUserRequest(userId));

		return mapper.mapFromGrpc(grpcUserProfileResponse.getUserProfile());
	}

	private GrpcGetUserProfileRequest buildGetUserRequest(OzgCloudUserId id) {
		return GrpcGetUserProfileRequest.newBuilder().setUserId(id.toString())
				.build();
	}

	private UserProfileServiceBlockingStub getUserProfileServiceStub() {
		return serviceStub.withInterceptors(new OzgCloudCallContextAttachingInterceptor(contextProvider));
	}
}
