/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.vorgang.grpc;

import java.util.Optional;

import org.mapstruct.Mapper;
import org.mapstruct.Mapping;

import de.ozgcloud.apilib.user.OzgCloudUserId;
import de.ozgcloud.apilib.vorgang.OzgCloudServiceKontoType;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgang;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangIdMapper;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangStatus;
import de.ozgcloud.vorgang.vorgang.GrpcVorgangWithEingang;

@Mapper(uses = { OzgCloudEingangMapper.class, OzgCloudVorgangIdMapper.class })
public interface OzgCloudVorgangMapper {

	@Mapping(target = "eingangs", ignore = true)
	@Mapping(target = "vorgangNummer", source = "nummer")
	@Mapping(target = "vorgangName", source = "name")
	@Mapping(target = "header.aktenzeichen", source = "aktenzeichen")
	@Mapping(target = "header.assignedTo", source = "assignedTo")
	@Mapping(target = "header.createdAt", source = "createdAt")
	@Mapping(target = "header.status", source = "status")
	OzgCloudVorgang fromGrpc(GrpcVorgangWithEingang response);

	default OzgCloudServiceKontoType toOzgCloudServiceKontoType(String type) {
		return Optional.ofNullable(type).map(OzgCloudServiceKontoType::from).orElse(null);
	}

	default OzgCloudUserId toUserId(String userId) {
		return Optional.ofNullable(userId).map(OzgCloudUserId::from).orElse(null);
	}

	default OzgCloudVorgangStatus toVorgangId(String status) {
		return Optional.ofNullable(status).map(OzgCloudVorgangStatus::from).orElse(null);
	}
}
