/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.common.command.grpc;

import java.time.ZonedDateTime;
import java.util.Map;
import java.util.UUID;

import de.ozgcloud.apilib.common.command.OzgCloudCommand;
import de.ozgcloud.apilib.common.command.OzgCloudCommandId;
import de.ozgcloud.apilib.common.command.OzgCloudCommandStatus;
import de.ozgcloud.apilib.file.OzgCloudFileTestFactory;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangId;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangTestFactory;
import de.ozgcloud.common.datatype.StringBasedValue;

public class OzgCloudCommandTestFactory {

	public static final OzgCloudCommandId ID = OzgCloudCommandId.from(UUID.randomUUID().toString());

	public static final OzgCloudVorgangId VORGANG_ID = OzgCloudVorgangTestFactory.ID;
	public static final StringBasedValue RELATION_ID = OzgCloudFileTestFactory.ID;
	public static final long RELATION_VERSION = 42;

	public static final String ORDER = "CREATE_NOTE";
	public static final OzgCloudCommandStatus STATUS = OzgCloudCommandStatus.FINISHED;

	private static final String CREATED_AT_STR = "2023-08-18T13:54:10Z";
	private static final ZonedDateTime CREATED_AT = ZonedDateTime.parse(CREATED_AT_STR);
	private static final String FINISHED_AT_STR = "2023-08-18T13:55:10Z";
	private static final ZonedDateTime FINISHED_AT = ZonedDateTime.parse(FINISHED_AT_STR);

	public static final String BODY_FIELD_NAME = "FIELD";
	public static final Long BODY_FIELD_VALUE = 42L;
	private static final Map<String, Object> BODY = Map.of(BODY_FIELD_NAME, BODY_FIELD_VALUE);

	public static OzgCloudCommand create() {
		return createBuilder().build();
	}

	public static OzgCloudCommand.OzgCloudCommandBuilder createBuilder() {
		return OzgCloudCommand.builder()
				.id(ID)
				.vorgangId(VORGANG_ID)
				.relationId(RELATION_ID)
				.relationVersion(RELATION_VERSION)
				.order(ORDER)
				.status(STATUS)
				.createdAt(CREATED_AT)
				.finishedAt(FINISHED_AT)
				.bodyObject(BODY);
	}
}
