/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.user;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.ArgumentCaptor;
import org.mockito.Captor;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.apilib.common.callcontext.OzgCloudCallContextProvider;
import de.ozgcloud.user.grpc.userprofile.UserProfileServiceGrpc.UserProfileServiceBlockingStub;
import de.ozgcloud.user.userprofile.GrpcGetUserProfileRequest;

class GrpcOzgCloudUserProfileServiceTest {

	@InjectMocks
	private GrpcOzgCloudUserProfileService service;

	@Mock
	private UserProfileServiceBlockingStub userProfileServiceStub;
	@Mock
	private UserProfileMapper mapper;

	@Mock
	private OzgCloudCallContextProvider contextProvider;

	@BeforeEach
	void prepareStubMock() {
		when(userProfileServiceStub.withInterceptors(any())).thenReturn(userProfileServiceStub);
	}

	@Nested
	class TestGetById {

		@Captor
		private ArgumentCaptor<GrpcGetUserProfileRequest> requestCaptor;

		private OzgCloudUserProfile mappedUserProfile = OzgCloudUserProfileTestFactory.create();

		@BeforeEach
		void init() {
			when(userProfileServiceStub.getById(any())).thenReturn(
					GrpcGetUserProfileResponseTestFactory.create());
			when(mapper.mapFromGrpc(any())).thenReturn(mappedUserProfile);
		}

		@Test
		void shouldCallStub() {
			service.getById(OzgCloudUserProfileTestFactory.ID);

			verify(userProfileServiceStub).getById(requestCaptor.capture());
			assertThat(requestCaptor.getValue().getUserId()).isEqualTo(
					OzgCloudUserProfileTestFactory.ID.toString());
		}

		@Test
		void shouldCallMapper() {
			service.getById(OzgCloudUserProfileTestFactory.ID);

			verify(mapper).mapFromGrpc(any());
		}

		@Test
		void shouldReturnResult() {
			var result = service.getById(OzgCloudUserProfileTestFactory.ID);

			assertThat(result).isSameAs(mappedUserProfile);
		}

		@Test
		void shouldAddInterceptor() {
			service.getById(OzgCloudUserProfileTestFactory.ID);

			verify(userProfileServiceStub).withInterceptors(notNull());
		}
	}

}
