/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.vorgang;

import java.util.List;

public class OzgCloudVorgangEingangTestFactory {

	public static final String FIELD_NAME = "firstname";
	public static final String FIELD_LABEL = "Firstname";
	public static final String FIELD_VALUE = "Klaus";

	public static final String SUB_FORM_NAME = "address";
	public static final String SUB_FORM_LABEL = "Address";
	public static final String SUB_FORM_FIELD_NAME = "street";
	public static final String SUB_FORM_FIELD_LABEL = "Street";
	public static final String SUB_FORM_FIELD_VALUE = "Mainstreet 5";

	public static OzgCloudEingang create() {
		return createBuilder().build();
	}

	public static OzgCloudEingang.OzgCloudEingangBuilder createBuilder() {
		return OzgCloudEingang.builder()
				.header(OzgCloudEingangHeaderTestFactory.create())
				.antragsteller(OzgCloudAntragstellerTestFactory.create())
				.zustaendigeStelle(OzgCloudZustaendigeStelleTestFactory.create())
				.attachments(List.of(AttachmentTestFactory.createFileGroup()))
				.formDataEntrys(List.<OzgCloudFormDataEntry>of(
						OzgCloudFormField.builder().name(FIELD_NAME).label(FIELD_LABEL).value(FIELD_VALUE).build(),
						OzgCloudSubForm.builder().name(SUB_FORM_NAME).label(SUB_FORM_LABEL)
								.formEntry(OzgCloudFormField.builder()
										.name(SUB_FORM_FIELD_NAME)
										.label(SUB_FORM_FIELD_LABEL)
										.value(SUB_FORM_FIELD_VALUE).build())
								.build()));
	}
}
