/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.vorgang.grpc;

import static de.ozgcloud.apilib.vorgang.OzgCloudVorgangEingangTestFactory.*;

import de.ozgcloud.vorgang.vorgang.GrpcEingang;
import de.ozgcloud.vorgang.vorgang.GrpcFormData;
import de.ozgcloud.vorgang.vorgang.GrpcFormField;
import de.ozgcloud.vorgang.vorgang.GrpcSubForm;

public class GrpcEingangTestFactory {

	public static GrpcEingang create() {
		return createBuilder().build();
	}

	public static GrpcEingang.Builder createBuilder() {
		return GrpcEingang.newBuilder()
				.setHeader(GrpcEingangHeaderTestFactory.create())
				.setAntragsteller(GrpcAntragstellerTestFactory.create())
				.setZustaendigeStelle(GrpcZustaendigeStelleTestFactory.create())
				.setFormData(createFormData());
	}

	public static GrpcFormData createFormData() {
		return GrpcFormData.newBuilder()
				.addField(GrpcFormField.newBuilder().setName(FIELD_NAME).setLabel(FIELD_LABEL).setValue(FIELD_VALUE).build())
				.addForm(GrpcSubForm.newBuilder().setTitle(SUB_FORM_NAME).setLabel(SUB_FORM_LABEL)
						.addField(GrpcFormField.newBuilder()
								.setName(SUB_FORM_FIELD_NAME)
								.setLabel(SUB_FORM_FIELD_LABEL)
								.setValue(SUB_FORM_FIELD_VALUE).build()))
				.build();
	}
}
