/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.vorgang.grpc;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Spy;

import de.ozgcloud.apilib.vorgang.OzgCloudVorgangEingangTestFactory;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangHeaderTestFactory;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangIdMapper;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangTestFactory;

class OzgCloudVorgangMapperTest {

	@InjectMocks
	private OzgCloudVorgangMapper mapper = Mappers.getMapper(OzgCloudVorgangMapper.class);

	@Spy
	private OzgCloudEingangMapper eingangMapper = Mappers.getMapper(OzgCloudEingangMapper.class);
	@Spy
	private OzgCloudVorgangIdMapper idMapper = Mappers.getMapper(OzgCloudVorgangIdMapper.class);

	@Nested
	class TestFromGrpc {
		@Test
		void shouldMapVorgangStub() {
			var mapped = mapper.fromGrpc(GrpcVorgangWithEingangTestFactory.create());

			assertThat(mapped).usingRecursiveComparison()
					.ignoringFields("eingangs", "header")
					.isEqualTo(OzgCloudVorgangTestFactory.create());
		}

		@Test
		void shouldMapHeader() {
			var mapped = mapper.fromGrpc(GrpcVorgangWithEingangTestFactory.create());

			assertThat(mapped.getHeader()).usingRecursiveComparison()
					.isEqualTo(OzgCloudVorgangHeaderTestFactory.create());
		}

		@Test
		void shouldMapEingang() {
			var mapped = mapper.fromGrpc(GrpcVorgangWithEingangTestFactory.create());

			assertThat(mapped.getEingangs()).hasSize(1).first()
					.usingRecursiveComparison().ignoringFields("attachments")
					.isEqualTo(OzgCloudVorgangEingangTestFactory.create());
		}
	}

}
